==> libopenshot-audio-docs-0.3.2-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/classjuce_1_1AudioIODevice.js <==
var classjuce_1_1AudioIODevice =
[
    [ "~AudioIODevice", "classjuce_1_1AudioIODevice.html#adf06fad7c5656b11534f09c839db1820", null ],
    [ "AudioIODevice", "classjuce_1_1AudioIODevice.html#a80e47f72811da67e16433c3f656d53ef", null ],
    [ "close", "classjuce_1_1AudioIODevice.html#a10ae7bd0cb6e249c04420a37a1076030", null ],
    [ "getActiveInputChannels", "classjuce_1_1AudioIODevice.html#a757da9f5cbd199b0566acb716728cdb8", null ],
    [ "getActiveOutputChannels", "classjuce_1_1AudioIODevice.html#a88a6e2f3e29c7898f3b8072eee834120", null ],
    [ "getAvailableBufferSizes", "classjuce_1_1AudioIODevice.html#a57e089ec70e024b99f49558bd12fa064", null ],
    [ "getAvailableSampleRates", "classjuce_1_1AudioIODevice.html#a8a0c9fc5e583f515a5af36a722ad8d38", null ],
    [ "getCurrentBitDepth", "classjuce_1_1AudioIODevice.html#a0b88759ce354d8411d6aae1a53a73c2c", null ],
    [ "getCurrentBufferSizeSamples", "classjuce_1_1AudioIODevice.html#a9f9c0afaff542970832dd1a2ae66c95e", null ],
    [ "getCurrentSampleRate", "classjuce_1_1AudioIODevice.html#a006a610e33f6805f8b33331bc104aef5", null ],
    [ "getDefaultBufferSize", "classjuce_1_1AudioIODevice.html#ac93873049d59f70b2161162da6ac2b67", null ],
    [ "getInputChannelNames", "classjuce_1_1AudioIODevice.html#a3b418689d2fbdc48965d022aae58c6c6", null ],
    [ "getInputLatencyInSamples", "classjuce_1_1AudioIODevice.html#a90201c4b15907114fcbfc0431ba56d7e", null ],
    [ "getLastError", "classjuce_1_1AudioIODevice.html#adba5f7eefae437212ae6ee14c94a3b8f", null ],
    [ "getName", "classjuce_1_1AudioIODevice.html#aa6d01a5a62e632625e42d279331e5a79", null ],
    [ "getOutputChannelNames", "classjuce_1_1AudioIODevice.html#a30bc03f3819dfe0dd8edd96728400111", null ],
    [ "getOutputLatencyInSamples", "classjuce_1_1AudioIODevice.html#ae8d82565fcd491a7299a6cdeee3ca23d", null ],
    [ "getTypeName", "classjuce_1_1AudioIODevice.html#a20bea29e2b513cef14d547d3f9a8bc86", null ],
    [ "getXRunCount", "classjuce_1_1AudioIODevice.html#a9cd4a02c7eedb4f27af94a1db9e83601", null ],
    [ "hasControlPanel", "classjuce_1_1AudioIODevice.html#a08111e99ae258b89dc6952ff8773471a", null ],
    [ "isOpen", "classjuce_1_1AudioIODevice.html#aee313d9e507761b349012a3822fd22ea", null ],
    [ "isPlaying", "classjuce_1_1AudioIODevice.html#a10eb13017792493e96387b132ea25477", null ],
    [ "open", "classjuce_1_1AudioIODevice.html#ae2a8aae2ca2eaee6af3dd10a245ffc64", null ],
    [ "setAudioPreprocessingEnabled", "classjuce_1_1AudioIODevice.html#afb41988be1b5232612186e01824f7f08", null ],
    [ "showControlPanel", "classjuce_1_1AudioIODevice.html#add1e66b6300b14d176112cbaccbb2fe7", null ],
    [ "start", "classjuce_1_1AudioIODevice.html#ada4184e9bcc35558fa58093ea5730538", null ],
    [ "stop", "classjuce_1_1AudioIODevice.html#a76d95aaadc920b04d9fc8ab502ec2d51", null ],
    [ "name", "classjuce_1_1AudioIODevice.html#a70b01d1bfd0e736b39b4ebb2ab464e38", null ]
];

==> libopenshot-audio-docs-0.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/classjuce_1_1AudioIODevice.js <==
var classjuce_1_1AudioIODevice =
[
    [ "~AudioIODevice", "classjuce_1_1AudioIODevice.html#adf06fad7c5656b11534f09c839db1820", null ],
    [ "AudioIODevice", "classjuce_1_1AudioIODevice.html#a80e47f72811da67e16433c3f656d53ef", null ],
    [ "close", "classjuce_1_1AudioIODevice.html#a10ae7bd0cb6e249c04420a37a1076030", null ],
    [ "getActiveInputChannels", "classjuce_1_1AudioIODevice.html#a757da9f5cbd199b0566acb716728cdb8", null ],
    [ "getActiveOutputChannels", "classjuce_1_1AudioIODevice.html#a88a6e2f3e29c7898f3b8072eee834120", null ],
    [ "getAvailableBufferSizes", "classjuce_1_1AudioIODevice.html#a57e089ec70e024b99f49558bd12fa064", null ],
    [ "getAvailableSampleRates", "classjuce_1_1AudioIODevice.html#a8a0c9fc5e583f515a5af36a722ad8d38", null ],
    [ "getCurrentBitDepth", "classjuce_1_1AudioIODevice.html#a0b88759ce354d8411d6aae1a53a73c2c", null ],
    [ "getCurrentBufferSizeSamples", "classjuce_1_1AudioIODevice.html#a9f9c0afaff542970832dd1a2ae66c95e", null ],
    [ "getCurrentSampleRate", "classjuce_1_1AudioIODevice.html#a006a610e33f6805f8b33331bc104aef5", null ],
    [ "getDefaultBufferSize", "classjuce_1_1AudioIODevice.html#ac93873049d59f70b2161162da6ac2b67", null ],
    [ "getDefaultInputChannels", "classjuce_1_1AudioIODevice.html#a50e4a53caab77715613046c9e5d3373c", null ],
    [ "getDefaultOutputChannels", "classjuce_1_1AudioIODevice.html#a68e5da9da2b6f2c453812d2de670e6fe", null ],
    [ "getInputChannelNames", "classjuce_1_1AudioIODevice.html#a3b418689d2fbdc48965d022aae58c6c6", null ],
    [ "getInputLatencyInSamples", "classjuce_1_1AudioIODevice.html#a90201c4b15907114fcbfc0431ba56d7e", null ],
    [ "getLastError", "classjuce_1_1AudioIODevice.html#adba5f7eefae437212ae6ee14c94a3b8f", null ],
    [ "getName", "classjuce_1_1AudioIODevice.html#aa6d01a5a62e632625e42d279331e5a79", null ],
    [ "getOutputChannelNames", "classjuce_1_1AudioIODevice.html#a30bc03f3819dfe0dd8edd96728400111", null ],
    [ "getOutputLatencyInSamples", "classjuce_1_1AudioIODevice.html#ae8d82565fcd491a7299a6cdeee3ca23d", null ],
    [ "getTypeName", "classjuce_1_1AudioIODevice.html#a20bea29e2b513cef14d547d3f9a8bc86", null ],
    [ "getWorkgroup", "classjuce_1_1AudioIODevice.html#a5c0fba35cdd0ad6558e50e2f44542086", null ],
    [ "getXRunCount", "classjuce_1_1AudioIODevice.html#a9cd4a02c7eedb4f27af94a1db9e83601", null ],
    [ "hasControlPanel", "classjuce_1_1AudioIODevice.html#a08111e99ae258b89dc6952ff8773471a", null ],
    [ "isOpen", "classjuce_1_1AudioIODevice.html#aee313d9e507761b349012a3822fd22ea", null ],
    [ "isPlaying", "classjuce_1_1AudioIODevice.html#a10eb13017792493e96387b132ea25477", null ],
    [ "open", "classjuce_1_1AudioIODevice.html#ae2a8aae2ca2eaee6af3dd10a245ffc64", null ],
    [ "setAudioPreprocessingEnabled", "classjuce_1_1AudioIODevice.html#afb41988be1b5232612186e01824f7f08", null ],
    [ "showControlPanel", "classjuce_1_1AudioIODevice.html#add1e66b6300b14d176112cbaccbb2fe7", null ],
    [ "start", "classjuce_1_1AudioIODevice.html#ada4184e9bcc35558fa58093ea5730538", null ],
    [ "stop", "classjuce_1_1AudioIODevice.html#a76d95aaadc920b04d9fc8ab502ec2d51", null ],
    [ "name", "classjuce_1_1AudioIODevice.html#a70b01d1bfd0e736b39b4ebb2ab464e38", null ]
];
